# serial-mecab
mecab-python3 wrapper for serialization.
## Build status
[![CircleCI](https://circleci.com/gh/nryotaro/serial-mecab.svg?style=svg)](https://circleci.com/gh/nryotaro/serial-mecab)
## API documents
- [0.0.1](https://nryotaro.dev/serial-mecab/0.0.1/)
